@@ -8,12 +8,12 @@ from ..misc import find_closest
 
 
 def eda_plot(eda_signals, sampling_rate=None):
-    """Visualize electrodermal activity (EDA) data.
+    """**Visualize electrodermal activity (EDA) data**
 
     Parameters
     ----------
     eda_signals : DataFrame
-        DataFrame obtained from `eda_process()`.
+        DataFrame obtained from :func:`eda_process()`.
     sampling_rate : int
         The desired sampling rate (in Hz, i.e., samples/second). Defaults to None.
 
@@ -24,12 +24,16 @@ def eda_plot(eda_signals, sampling_rate=None):
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0, sampling_rate=250)
-    >>> eda_signals, info = nk.eda_process(eda_signal, sampling_rate=250)
-    >>> fig = nk.eda_plot(eda_signals)
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0, sampling_rate=250)
+      eda_signals, info = nk.eda_process(eda_signal, sampling_rate=250)
+      @savefig p_eda_plot1.png scale=100%
+      nk.eda_plot(eda_signals)
+      @suppress
+      plt.close()
 
     See Also
     --------
@@ -59,21 +63,32 @@ def eda_plot(eda_signals, sampling_rate=None):
     fig.suptitle("Electrodermal Activity (EDA)", fontweight="bold")
 
     ax0.plot(x_axis, eda_signals["EDA_Raw"], color="#B0BEC5", label="Raw", zorder=1)
-    ax0.plot(x_axis, eda_signals["EDA_Clean"], color="#9C27B0", label="Cleaned", linewidth=1.5, zorder=1)
+    ax0.plot(
+        x_axis, eda_signals["EDA_Clean"], color="#9C27B0", label="Cleaned", linewidth=1.5, zorder=1
+    )
     ax0.legend(loc="upper right")
 
     # Plot skin cnoductance response.
     ax1.set_title("Skin Conductance Response (SCR)")
 
     # Plot Phasic.
-    ax1.plot(x_axis, eda_signals["EDA_Phasic"], color="#E91E63", label="Phasic Component", linewidth=1.5, zorder=1)
+    ax1.plot(
+        x_axis,
+        eda_signals["EDA_Phasic"],
+        color="#E91E63",
+        label="Phasic Component",
+        linewidth=1.5,
+        zorder=1,
+    )
 
     # Mark segments.
     risetime_coord, amplitude_coord, halfr_coord = _eda_plot_dashedsegments(
         eda_signals, ax1, x_axis, onsets, peaks, half_recovery
     )
 
-    risetime = matplotlib.collections.LineCollection(risetime_coord, colors="#FFA726", linewidths=1, linestyle="dashed")
+    risetime = matplotlib.collections.LineCollection(
+        risetime_coord, colors="#FFA726", linewidths=1, linestyle="dashed"
+    )
     ax1.add_collection(risetime)
 
     amplitude = matplotlib.collections.LineCollection(
@@ -81,16 +96,18 @@ def eda_plot(eda_signals, sampling_rate=None):
     )
     ax1.add_collection(amplitude)
 
-    halfr = matplotlib.collections.LineCollection(halfr_coord, colors="#FDD835", linewidths=1, linestyle="dashed")
+    halfr = matplotlib.collections.LineCollection(
+        halfr_coord, colors="#FDD835", linewidths=1, linestyle="dashed"
+    )
     ax1.add_collection(halfr)
     ax1.legend(loc="upper right")
 
     # Plot Tonic.
     ax2.set_title("Skin Conductance Level (SCL)")
-    ax2.plot(x_axis, eda_signals["EDA_Tonic"], color="#673AB7", label="Tonic Component", linewidth=1.5)
+    ax2.plot(
+        x_axis, eda_signals["EDA_Tonic"], color="#673AB7", label="Tonic Component", linewidth=1.5
+    )
     ax2.legend(loc="upper right")
-    plt.show()
-    return fig
 
 
 # =============================================================================
@@ -99,10 +116,18 @@ def eda_plot(eda_signals, sampling_rate=None):
 def _eda_plot_dashedsegments(eda_signals, ax, x_axis, onsets, peaks, half_recovery):
     # Mark onsets, peaks, and half-recovery.
     scat_onset = ax.scatter(
-        x_axis[onsets], eda_signals["EDA_Phasic"][onsets], color="#FFA726", label="SCR - Onsets", zorder=2
+        x_axis[onsets],
+        eda_signals["EDA_Phasic"][onsets],
+        color="#FFA726",
+        label="SCR - Onsets",
+        zorder=2,
     )
     scat_peak = ax.scatter(
-        x_axis[peaks], eda_signals["EDA_Phasic"][peaks], color="#1976D2", label="SCR - Peaks", zorder=2
+        x_axis[peaks],
+        eda_signals["EDA_Phasic"][peaks],
+        color="#1976D2",
+        label="SCR - Peaks",
+        zorder=2,
     )
     scat_halfr = ax.scatter(
         x_axis[half_recovery],
@@ -111,7 +136,9 @@ def _eda_plot_dashedsegments(eda_signals, ax, x_axis, onsets, peaks, half_recove
         label="SCR - Half recovery",
         zorder=2,
     )
-    end_onset = pd.Series(eda_signals["EDA_Phasic"][onsets].values, eda_signals["EDA_Phasic"][peaks].index)
+    end_onset = pd.Series(
+        eda_signals["EDA_Phasic"][onsets].values, eda_signals["EDA_Phasic"][peaks].index
+    )
     scat_endonset = ax.scatter(x_axis[end_onset.index], end_onset.values, alpha=0)
 
     # Rise time.
@@ -129,7 +156,9 @@ def _eda_plot_dashedsegments(eda_signals, ax, x_axis, onsets, peaks, half_recove
 
     peak_list = []
     for i, index in enumerate(half_recovery):
-        value = find_closest(recovery_x_values[i], peak_x_values, direction="smaller", strictly=False)
+        value = find_closest(
+            recovery_x_values[i], peak_x_values, direction="smaller", strictly=False
+        )
         peak_list.append(value)
 
     peak_index = []
