@@ -54,19 +54,18 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
           extracted from n-minute segments of time series data (1, 2 and 5 by default). Note that
           these indices require a minimal duration of signal to be computed (3, 6 and 15 minutes
           respectively) and will be silently skipped if the data provided is too short.
-        * **RMSSD**: The square root of the mean of the sum of successive differences between
+        * **RMSSD**: The square root of the mean of the squared successive differences between
           adjacent RR intervals. It is equivalent (although on another scale) to SD1, and
           therefore it is redundant to report correlations with both (Ciccone, 2017).
         * **SDSD**: The standard deviation of the successive differences between RR intervals.
         * **CVNN**: The standard deviation of the RR intervals (**SDNN**) divided by the mean of
           the RR intervals (**MeanNN**).
-        * **CVSD**: The root mean square of the sum of successive differences (**RMSSD**) divided by
+        * **CVSD**: The root mean square of successive differences (**RMSSD**) divided by
           the mean of the RR intervals (**MeanNN**).
-        * **MedianNN**: The median of the absolute values of the successive differences between RR
-          intervals.
+        * **MedianNN**: The median of the RR intervals.
         * **MadNN**: The median absolute deviation of the RR intervals.
-        * **HCVNN**: The median absolute deviation of the RR intervals (**MadNN**) divided by the
-          median of the absolute differences of their successive differences (**MedianNN**).
+        * **MCVNN**: The median absolute deviation of the RR intervals (**MadNN**) divided by the
+          median of the RR intervals (**MedianNN**).
         * **IQRNN**: The interquartile range (**IQR**) of the RR intervals.
         * **Prc20NN**: The 20th percentile of the RR intervals (Han, 2017; Hovsepian, 2015).
         * **Prc80NN**: The 80th percentile of the RR intervals (Han, 2017; Hovsepian, 2015).
