@@ -4,7 +4,7 @@ from warnings import warn
 import numpy as np
 import pandas as pd
 
-from ..misc import as_vector, NeuroKitWarning
+from ..misc import NeuroKitWarning, as_vector
 from ..signal import signal_filter
 
 
@@ -73,7 +73,7 @@ def ppg_clean(ppg_signal, sampling_rate=1000, heart_rate=None, method="elgendi")
         warn(
             "There are " + str(n_missing) + " missing data points in your signal."
             " Filling missing values by using the forward filling method.",
-            category=NeuroKitWarning
+            category=NeuroKitWarning,
         )
         ppg_signal = _ppg_clean_missing(ppg_signal)
 
@@ -97,21 +97,27 @@ def _ppg_clean_missing(ppg_signal):
 
     return ppg_signal
 
+
 # =============================================================================
 # Methods
 # =============================================================================
 
+
 def _ppg_clean_elgendi(ppg_signal, sampling_rate):
 
     filtered = signal_filter(
-        ppg_signal, sampling_rate=sampling_rate, lowcut=0.5, highcut=8, order=3, method="butter_ba"
+        ppg_signal,
+        sampling_rate=sampling_rate,
+        lowcut=0.5,
+        highcut=8,
+        order=3,
+        method="butterworth",
     )
     return filtered
 
 
 def _ppg_clean_nabian2018(ppg_signal, sampling_rate, heart_rate=None):
-    """Low-pass filter for continuous BP signal preprocessing, adaopted from Nabian et al. (2018).
-    """
+    """Low-pass filter for continuous BP signal preprocessing, adaopted from Nabian et al. (2018)."""
 
     # Determine low-pass filter value
     highcut = 40
@@ -120,10 +126,19 @@ def _ppg_clean_nabian2018(ppg_signal, sampling_rate, heart_rate=None):
     if heart_rate is not None:
         heart_rate = heart_rate / 60
 
-        if not highcut >= 10*heart_rate and not highcut < 0.5*sampling_rate:
-            raise ValueError("Highcut value should be at least 10 times heart rate and"
-                             " less than 0.5 times sampling rate.")
+        if not highcut >= 10 * heart_rate and not highcut < 0.5 * sampling_rate:
+            raise ValueError(
+                "Highcut value should be at least 10 times heart rate and"
+                " less than 0.5 times sampling rate."
+            )
 
-    filtered = signal_filter(ppg_signal, sampling_rate=sampling_rate, lowcut=None, highcut=highcut, order=2, method="butterworth")
+    filtered = signal_filter(
+        ppg_signal,
+        sampling_rate=sampling_rate,
+        lowcut=None,
+        highcut=highcut,
+        order=2,
+        method="butterworth",
+    )
 
     return filtered
