@@ -15,6 +15,7 @@ from .rsp_phase import rsp_phase
 from .rsp_plot import rsp_plot
 from .rsp_process import rsp_process
 from .rsp_rrv import rsp_rrv
+from .rsp_rvt import rsp_rvt
 from .rsp_simulate import rsp_simulate
 
 
@@ -30,6 +31,7 @@ __all__ = [
     "rsp_plot",
     "rsp_eventrelated",
     "rsp_rrv",
+    "rsp_rvt",
     "rsp_intervalrelated",
     "rsp_analyze",
     "rsp_rate",
