@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 import numpy as np
 
-from ..signal import signal_filter, signal_interpolate, signal_rate, signal_resample
+from ..signal import (signal_filter, signal_interpolate, signal_rate,
+                      signal_resample)
 from .rsp_peaks import rsp_peaks
 
 
@@ -16,34 +17,36 @@ def rsp_rate(
     interpolation_method="monotone_cubic",
 ):
 
-    """Find respiration rate.
+    """**Find respiration rate**
 
     Parameters
     ----------
     rsp_cleaned : Union[list, np.array, pd.Series]
-        The cleaned respiration channel as returned by `rsp_clean()`.
+        The cleaned respiration channel as returned by :func:`.rsp_clean`.
     troughs : Union[list, np.array, pd.Series, pd.DataFrame]
-        The respiration troughs (inhalation onsets) as returned by `rsp_peaks()`.
+        The respiration troughs (inhalation onsets) as returned by :func:`.rsp_peaks`.
         If None (default), inhalation onsets will be automatically identified from the
-        `rsp_clean` signal.
+        :func:`.rsp_clean` signal.
     sampling_rate : int
-        The sampling frequency of 'rsp_cleaned' (in Hz, i.e., samples/second).
+        The sampling frequency of :func:`.rsp_cleaned` (in Hz, i.e., samples/second).
     window : int
         The duration of the sliding window (in second). Default to 10 seconds.
     hop_size : int
         The number of samples between each successive window. Default to 1 sample.
     method : str
-        Method can either be "trough" or "xcorr". In "trough" method, respiratory rate is calculated from the
-        periods between successive inspirations (i.e., inhalation onsets/troughs).
-        In "xcorr" method, cross-correlations between the changes in respiration with a bank of
-        sinusoids of different frequencies are caclulated to indentify the principal frequency of oscillation.
+        Method can either be ``"trough"`` or ``"xcorr"``. In ``"trough"`` method, respiratory rate
+        is calculated from the periods between successive inspirations (i.e., inhalation onsets/
+        troughs). In ``"xcorr"`` method, cross-correlations between the changes in respiration with
+        a bank of sinusoids of different frequencies are calculated to identify the principal
+        frequency of oscillation.
     peak_method : str
-        Method to identify successive respiratory inspirations, only relevant if method is "trough".
-        Can be one of "khodadad2018" (default) or "biosppy".
+        Method to identify successive respiratory inspirations, only relevant if method is
+        ``"trough"``. Can be one of ``"khodadad2018"`` (default) or ``"biosppy"``.
     interpolation_method : str
-        Method used to interpolate the rate between inhalation onsets. See `signal_interpolate()`. 'monotone_cubic'
-        is chosen as the default interpolation method since it ensures monotone interpolation between
-        data points (i.e., it prevents physiologically implausible "overshoots" or "undershoots" in the
+        Method used to interpolate the rate between inhalation onsets.
+        See :func:`.signal_interpolate`. ``"monotone_cubic"`` is chosen as the default
+        interpolation method since it ensures monotone interpolation between data points (i.e., it
+        prevents physiologically implausible "overshoots" or "undershoots" in the
         y-direction). In contrast, the widely used cubic spline interpolation does not ensure
         monotonicity.
 
@@ -54,12 +57,14 @@ def rsp_rate(
 
     Example
     -------
-    >>> import neurokit2 as nk
-    >>> rsp_signal = nk.data("rsp_200hz.txt").iloc[:,0]
-    >>> sampling_rate=200
-    >>> rsp_cleaned = nk.rsp_clean(rsp_signal, sampling_rate=sampling_rate)
-    >>> rsp_rate_onsets = nk.rsp_rate(rsp_cleaned, sampling_rate=sampling_rate, method="trough")
-    >>> rsp_rate_xcorr = nk.rsp_rate(rsp_cleaned, sampling_rate=sampling_rate, method="xcorr")
+    .. ipython:: python
+
+      import neurokit2 as nk
+      rsp_signal = nk.data("rsp_1000hz")
+
+      rsp_cleaned = nk.rsp_clean(rsp_signal, sampling_rate=1000)
+      rsp_rate_onsets = nk.rsp_rate(rsp_cleaned, sampling_rate=1000, method="trough")
+      rsp_rate_xcorr = nk.rsp_rate(rsp_cleaned, sampling_rate=1000, method="xcorr")
     """
 
     if method.lower() in ["period", "peak", "peaks", "trough", "troughs", "signal_rate"]:
