@@ -4,7 +4,11 @@ import pandas as pd
 
 
 def signal_formatpeaks(info, desired_length, peak_indices=None, other_indices=None):
-    """Transforms an peak-info dict to a signal of given length."""
+    """**Format Peaks**
+
+    Transforms a peak-info dict to a signal of given length
+
+    """
     if peak_indices is None:
         peak_indices = [key for key in info.keys() if "Peaks" in key]
 
@@ -50,7 +54,7 @@ def _signal_sanitize_indices(indices, values):
 
 
 def _signal_from_indices(indices, desired_length=None, value=1):
-    """Generates array of 0 and given values at given indices.
+    """**Generates array of 0 and given values at given indices**
 
     Used in *_findpeaks to transform vectors of peak indices to signal.
 
