@@ -6,21 +6,21 @@ import scipy.signal
 
 
 def signal_phase(signal, method="radians"):
-    """Compute the phase of the signal.
+    """**Compute the phase of the signal**
 
     The real phase has the property to rotate uniformly, leading to a uniform distribution density.
-    The prophase typically doesn't fulfill this property. The following functions applies a nonlinear
-    transformation to the phase signal that makes its distribution exactly uniform. If a binary vector
-    is provided (containing 2 unique values), the function will compute the phase of completion of each
-    phase as denoted by each value.
+    The prophase typically doesn't fulfill this property. The following functions applies a
+    nonlinear transformation to the phase signal that makes its distribution exactly uniform. If a
+    binary vector is provided (containing 2 unique values), the function will compute the phase of
+    completion of each phase as denoted by each value.
 
     Parameters
     ----------
     signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
     method : str
-        The values in which the phase is expressed. Can be 'radians' (default), 'degrees'
-        (for values between 0 and 360) or 'percents' (for values between 0 and 1).
+        The values in which the phase is expressed. Can be ``"radians"`` (default),
+        ``"degrees"`` (for values between 0 and 360) or ``"percents"`` (for values between 0 and 1).
 
     See Also
     --------
@@ -33,20 +33,33 @@ def signal_phase(signal, method="radians"):
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> signal = nk.signal_simulate(duration=10)
-    >>> phase = nk.signal_phase(signal)
-    >>> nk.signal_plot([signal, phase])
-    >>>
-    >>> rsp = nk.rsp_simulate(duration=30)
-    >>> phase = nk.signal_phase(rsp, method="degrees")
-    >>> nk.signal_plot([rsp, phase])
-    >>>
-    >>> # Percentage of completion of two phases
-    >>> signal = nk.signal_binarize(nk.signal_simulate(duration=10))
-    >>> phase = nk.signal_phase(signal, method="percents")
-    >>> nk.signal_plot([signal, phase])
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      signal = nk.signal_simulate(duration=10)
+      phase = nk.signal_phase(signal)
+      @savefig p_signal_phase1.png scale=100%
+      nk.signal_plot([signal, phase])
+      @suppress
+      plt.close()
+
+    ..ipython:: python
+
+      rsp = nk.rsp_simulate(duration=30)
+      phase = nk.signal_phase(rsp, method="degrees")
+      @savefig p_signal_phase2.png scale=100%
+      nk.signal_plot([rsp, phase])
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      # Percentage of completion of two phases
+      signal = nk.signal_binarize(nk.signal_simulate(duration=10))
+      phase = nk.signal_phase(signal, method="percents")
+      @savefig p_signal_phase3.png scale=100%
+      nk.signal_plot([signal, phase])
 
     """
     # If binary signal
