@@ -24,7 +24,7 @@ def signal_psd(
     silent=True,
     **kwargs,
 ):
-    """Compute the Power Spectral Density (PSD).
+    """**Compute the Power Spectral Density (PSD)**
 
     Parameters
     ----------
@@ -33,36 +33,39 @@ def signal_psd(
     sampling_rate : int
         The sampling frequency of the signal (in Hz, i.e., samples/second).
     method : str
-        Either 'welch' (default), 'fft', 'multitapers' (requires the 'mne' package), 'lombscargle'
-        (requires the 'astropy' package) or 'burg'.
+        Either ``"welch"`` (default), ``"fft"``, ``"multitapers"`` (requires the 'mne' package),
+        ``"lombscargle"`` (requires the 'astropy' package) or ``"burg"``.
     show : bool
-        If True, will return a plot. If False, will return the density values that can be plotted externally.
+        If ``True``, will return a plot. If ``False``, will return the density values that can be
+        plotted externally.
     normalize : bool
-        Normalization of power by maximum PSD value. Default to True.
+        Normalization of power by maximum PSD value. Default to ``True``.
         Normalization allows comparison between different PSD methods.
     min_frequency : str, float
-        The minimum frequency. If "default", min_frequency is chosen based on the sampling rate and length of signal to
-        optimize the frequency resolution.
+        The minimum frequency. If default, min_frequency is chosen based on the sampling rate and
+        length of signal to optimize the frequency resolution.
     max_frequency : float
         The maximum frequency.
     window : int
-        Length of each window in seconds (for Welch method). If None (default), window will be automatically
-        calculated to capture at least 2 cycles of min_frequency. If the length of recording does not
-        allow the formal, window will be default to half of the length of recording.
+        Length of each window in seconds (for "Welch" method). If ``None`` (default), window will be
+        automatically calculated to capture at least 2 cycles of min_frequency. If the length of
+        recording does not allow the formal, window will be default to half of the length of
+        recording.
     window_type : str
-        Desired window to use. Defaults to 'hann'. See ``scipy.signal.get_window()`` for list of windows.
+        Desired window to use. Defaults to ``"hann"``. See :func:`.scipy.signal.get_window` for list
+        of windows.
     order : int
-        The order of autoregression (only used for autoregressive (AR) methods such as 'burg').
+        The order of autoregression (only used for autoregressive (AR) methods such as ``"burg"``).
     order_criteria : str
         The criteria to automatically select order in parametric PSD (only used for autoregressive
-        (AR) methods such as 'burg').
+        (AR) methods such as ``"burg"``).
     order_corrected : bool
         Should the order criteria (AIC or KIC) be corrected? If unsure which method to use to choose
         the order, rely on the default (i.e., the corrected KIC).
     silent : bool
-        If False, warnings will be printed. Default to True.
+        If ``False``, warnings will be printed. Default to ``True``.
     **kwargs : optional
-        Keyword arguments to be passed to `scipy.signal.welch()`.
+        Keyword arguments to be passed to :func:`.scipy.signal.welch`.
 
     See Also
     --------
@@ -72,24 +75,53 @@ def signal_psd(
     -------
     data : pd.DataFrame
         A DataFrame containing the Power Spectrum values and a plot if
-        `show` is True.
+        ``show`` is ``True``.
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> signal = nk.signal_simulate(duration=2, frequency=[5, 6, 50, 52, 80], noise=0.5)
-    >>>
-    >>> # FFT method (based on numpy)
-    >>> psd_multitapers = nk.signal_psd(signal, method="fft", show=True)
-    >>> # Welch method (based on scipy)
-    >>> psd_welch = nk.signal_psd(signal, method="welch", min_frequency=1, show=True)
-    >>> # Multitapers method (requires MNE)
-    >>> psd_multitapers = nk.signal_psd(signal, method="multitapers", show=True)
-    >>> # Burg method
-    >>> psd_burg = nk.signal_psd(signal, method="burg", min_frequency=1, show=True)
-    >>> # Lomb method (requires AstroPy)
-    >>> psd_lomb = nk.signal_psd(signal, method="lomb", min_frequency=1, show=True)
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      signal = nk.signal_simulate(duration=2, frequency=[5, 6, 50, 52, 80], noise=0.5)
+
+      # FFT method (based on numpy)
+      @savefig p_signal_psd1.png scale=100%
+      psd_multitapers = nk.signal_psd(signal, method="fft", show=True)
+      @suppress
+      plt.close
+
+    .. ipython:: python
+
+      # Welch method (based on scipy)
+      @savefig p_signal_psd2.png scale=100%
+      psd_welch = nk.signal_psd(signal, method="welch", min_frequency=1, show=True)
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      # Multitapers method (requires MNE)
+      @savefig p_signal_psd3.png scale=100%
+      psd_multitapers = nk.signal_psd(signal, method="multitapers", show=True)
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      # Burg method
+      @savefig p_signal_psd4.png scale=100%
+      psd_burg = nk.signal_psd(signal, method="burg", min_frequency=1, show=True)
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      # Lomb method (requires AstroPy)
+      @savefig p_signal_psd5.png scale=100%
+      psd_lomb = nk.signal_psd(signal, method="lomb", min_frequency=1, show=True)
+      @suppress
+      plt.close()
 
     """
     # Constant Detrend
@@ -114,7 +146,7 @@ def signal_psd(
 
     # FFT (Numpy)
     elif method in ["fft"]:
-        frequency, power = _signal_psd_fft(signal, sampling_rate=sampling_rate)
+        frequency, power = _signal_psd_fft(signal, sampling_rate=sampling_rate, **kwargs)
 
     # Lombscargle (AtroPy)
     elif method.lower() in ["lombscargle", "lomb"]:
@@ -197,9 +229,9 @@ def signal_psd(
 # =============================================================================
 
 
-def _signal_psd_fft(signal, sampling_rate=1000):
+def _signal_psd_fft(signal, sampling_rate=1000, n=None):
     # Power-spectrum density (PSD)
-    power = np.abs(np.fft.rfft(signal)) ** 2
+    power = np.abs(np.fft.rfft(signal, n=n)) ** 2
     frequency = np.linspace(0, sampling_rate / 2, len(power))
     return frequency, power
 
