@@ -4,7 +4,7 @@ import scipy.linalg
 
 
 def fit_loess(y, X=None, alpha=0.75, order=2):
-    """Local Polynomial Regression (LOESS)
+    """**Local Polynomial Regression (LOESS)**
 
     Performs a LOWESS (LOcally WEighted Scatter-plot Smoother) regression.
 
@@ -14,7 +14,8 @@ def fit_loess(y, X=None, alpha=0.75, order=2):
     y : Union[list, np.array, pd.Series]
         The response variable (the y axis).
     X : Union[list, np.array, pd.Series]
-        Explanatory variable (the x axis). If 'None', will treat y as a continuous signal (useful for smoothing).
+        Explanatory variable (the x axis). If ``None``, will treat y as a continuous signal (useful
+        for smoothing).
     alpha : float
         The parameter which controls the degree of smoothing, which corresponds to the proportion
         of the samples to include in local regression.
@@ -24,7 +25,9 @@ def fit_loess(y, X=None, alpha=0.75, order=2):
     Returns
     -------
     array
-        Prediciton of the LOESS algorithm.
+        Prediction of the LOESS algorithm.
+    dict
+        Dictionary containing additional information such as the parameters (``order`` and ``alpha``).
 
     See Also
     ----------
@@ -32,18 +35,29 @@ def fit_loess(y, X=None, alpha=0.75, order=2):
 
     Examples
     ---------
-    >>> import pandas as pd
-    >>> import neurokit2 as nk
-    >>>
-    >>> signal = np.cos(np.linspace(start=0, stop=10, num=1000))
-    >>> distorted = nk.signal_distort(signal, noise_amplitude=[0.3, 0.2, 0.1], noise_frequency=[5, 10, 50])
-    >>>
-    >>> pd.DataFrame({ "Raw": distorted, "Loess_1": nk.fit_loess(distorted, order=1),
-    ...               "Loess_2": nk.fit_loess(distorted, order=2)}).plot() #doctest: +SKIP
+    .. ipython:: python
+
+      import pandas as pd
+      import neurokit2 as nk
+
+      # Simulate Signal
+      signal = np.cos(np.linspace(start=0, stop=10, num=1000))
+
+      # Add noise to signal
+      distorted = nk.signal_distort(signal,
+                                    noise_amplitude=[0.3, 0.2, 0.1],
+                                    noise_frequency=[5, 10, 50])
+
+      # Smooth signal using local regression
+      @savefig p_fit_loess1.png scale=100%
+      pd.DataFrame({ "Raw": distorted, "Loess_1": nk.fit_loess(distorted, order=1)[0],
+                     "Loess_2": nk.fit_loess(distorted, order=2)[0]}).plot()
+      @suppress
+      plt.close()
 
     References
     ----------
-    - https://simplyor.netlify.com/loess-from-scratch-in-python-animation.en-us/
+    * https://simplyor.netlify.com/loess-from-scratch-in-python-animation.en-us/
 
     """
     if X is None:
@@ -72,7 +86,7 @@ def fit_loess(y, X=None, alpha=0.75, order=2):
         delx0 = sorted_dist[span - 1]
 
         u = distance[ind[:span]] / delx0
-        w = (1 - u ** 3) ** 3
+        w = (1 - u**3) ** 3
 
         W = np.diag(w)
         A = np.vander(Nx, N=1 + order)
@@ -85,4 +99,4 @@ def fit_loess(y, X=None, alpha=0.75, order=2):
         y_predicted[i] = np.polyval(p, val)
         x_space[i] = val
 
-    return y_predicted
+    return y_predicted, {"alpha": alpha, "order": order}
